'use client';
// Chakra imports
import { Portal, Box, useDisclosure, useColorModeValue } from '@chakra-ui/react'
import Footer from '@/components/footer/FooterAdmin'
// Layout components
import Navbar from '@/components/navbar/NavbarAdmin'
import Sidebar from '@/components/sidebar/Sidebar'
import { SidebarContext } from '@/contexts/SidebarContext'
import { PropsWithChildren, useEffect, useState } from 'react'
import routes from '@/routes'
import {
  getActiveNavbar,
  getActiveNavbarText,
  getBrandTextFromURL,
} from '@/utils/navigation'
import { usePathname } from 'next/navigation';
import { useGeneral } from '@/contexts/GeneralContext';

interface DashboardLayoutProps extends PropsWithChildren {
  [x: string]: any
}

// Custom Chakra theme
export default function AdminLayout (props: DashboardLayoutProps) {
  const pathname = usePathname();
  const {currentUser} = useGeneral();
  const { children, ...rest } = props
  // states and functions
  const [fixed] = useState(false)
  const [toggleSidebar, setToggleSidebar] = useState(false)
  // functions for changing the states from components
  const { onOpen } = useDisclosure();
  const appRoutes = routes(currentUser.roles[0]);
  useEffect(() => {
    window.document.documentElement.dir = "ltr";
  });

  const bg = useColorModeValue("secondaryGray.300", "navy.900");

  return (
    <Box h="100vh" w="100vw" bg={bg}>
      <SidebarContext.Provider
        value={{
          toggleSidebar,
          setToggleSidebar,
        }}>
        <Sidebar routes={appRoutes} display="none" {...rest} />
        <Box float="right" minHeight="100vh" height="100%" overflow="auto" position="relative" maxHeight="100%" w={{ base: "100%", xl: "calc( 100% - 290px )" }} maxWidth={{ base: "100%", xl: "calc( 100% - 290px )" }} transition="all 0.33s cubic-bezier(0.685, 0.0473, 0.346, 1)" transitionDuration=".2s, .2s, .35s" transitionProperty="top, bottom, width" transitionTimingFunction="linear, linear, ease">
          <Portal>
            <Box>
              <Navbar message={getActiveNavbarText(appRoutes, pathname)} onOpen={onOpen} brandText={getBrandTextFromURL(pathname)} secondary={getActiveNavbar(appRoutes, pathname)} fixed={fixed} {...rest} />
            </Box>
          </Portal>

          <Box mx="auto" p={{ base: "20px", md: "30px" }} pe="20px" minH="100vh" pt="50px">
            {children}
          </Box>
          <Box>
            <Footer />
          </Box>
        </Box>
      </SidebarContext.Provider>
    </Box>
  );
}
